@@ -119,6 +119,8 @@ parse_format (const string& str)
     return Format::AUTO;
   if (str == "rf64")
     return Format::RF64;
+  if (str == "wav-pipe")
+    return Format::WAV_PIPE;
 
   error ("audiowmark: unsupported format '%s'\n", str.c_str());
   exit (1);
@@ -135,15 +137,39 @@ parse_endian (const string& str)
   exit (1);
 }
 
-RawFormat::Encoding
-parse_encoding (const string& str)
+void
+parse_encoding (const string& str, RawFormat& fmt)
 {
   if (str == "signed")
-    return RawFormat::Encoding::SIGNED;
-  if (str == "unsigned")
-    return RawFormat::Encoding::UNSIGNED;
-  error ("audiowmark: unsupported encoding '%s'\n", str.c_str());
-  exit (1);
+    fmt.set_encoding (Encoding::SIGNED);
+  else if (str == "unsigned")
+    fmt.set_encoding (Encoding::UNSIGNED);
+  else if (str == "float")
+    {
+      fmt.set_encoding (Encoding::FLOAT);
+      fmt.set_bit_depth (32);
+    }
+  else if (str == "double")
+    {
+      fmt.set_encoding (Encoding::FLOAT);
+      fmt.set_bit_depth (64);
+    }
+  else
+    {
+      error ("audiowmark: unsupported encoding '%s'\n", str.c_str());
+      exit (1);
+    }
+}
+
+void
+update_raw_bits (RawFormat& fmt, int bits)
+{
+  if (fmt.encoding() == Encoding::FLOAT)
+    {
+      error ("audiowmark: bit depth can not be changed for float / double encoding\n");
+      exit (1);
+    }
+  fmt.set_bit_depth (bits);
 }
 
 int
@@ -371,10 +397,9 @@ test_speed (const Key& key, int seed)
 }
 
 int
-test_gen_noise (const Key& key, const string& out_file, double seconds, int rate)
+test_gen_noise (const Key& key, const string& out_file, double seconds, int rate, int bits)
 {
   const int channels = 2;
-  const int bits = 16;
 
   vector<float> noise;
   Random rng (key, 0, /* there is no stream for this test */ Random::Stream::data_up_down);
@@ -431,6 +456,30 @@ test_resample (const string& in_file, const string& out_file, int new_rate)
   return 0;
 }
 
+int
+test_info (const string& in_file, const string& property)
+{
+  WavData in_data;
+  Error err = in_data.load (in_file);
+  if (err)
+    {
+      error ("audiowmark: error loading %s: %s\n", in_file.c_str(), err.message());
+      return 1;
+    }
+  if (property == "bit_depth")
+    {
+      printf ("%d\n", in_data.bit_depth());
+      return 0;
+    }
+  if (property == "frames")
+    {
+      printf ("%zd\n", in_data.n_frames());
+      return 0;
+    }
+  error ("audiowmark: unsupported property for test_info: %s\n", property.c_str());
+  return 1;
+}
+
 static string
 escape_key_name (const string& name)
 {
@@ -697,19 +746,6 @@ parse_add_options (ArgParser& ap)
     {
       Params::input_format = Params::output_format = parse_format (s);
     }
-  if (ap.parse_opt ("--raw-input-bits", i))
-    {
-      Params::raw_input_format.set_bit_depth (i);
-    }
-  if (ap.parse_opt ("--raw-output-bits", i))
-    {
-      Params::raw_output_format.set_bit_depth (i);
-    }
-  if (ap.parse_opt ("--raw-bits", i))
-    {
-      Params::raw_input_format.set_bit_depth (i);
-      Params::raw_output_format.set_bit_depth (i);
-    }
   if (ap.parse_opt ( "--raw-input-endian", s))
     {
       auto e = parse_endian (s);
@@ -728,19 +764,29 @@ parse_add_options (ArgParser& ap)
     }
   if (ap.parse_opt ("--raw-input-encoding", s))
     {
-      auto e = parse_encoding (s);
-      Params::raw_input_format.set_encoding (e);
+      parse_encoding (s, Params::raw_input_format);
     }
   if (ap.parse_opt ("--raw-output-encoding", s))
     {
-      auto e = parse_encoding (s);
-      Params::raw_output_format.set_encoding (e);
+      parse_encoding (s, Params::raw_output_format);
     }
   if (ap.parse_opt ("--raw-encoding", s))
     {
-      auto e = parse_encoding (s);
-      Params::raw_input_format.set_encoding (e);
-      Params::raw_output_format.set_encoding (e);
+      parse_encoding (s, Params::raw_input_format);
+      parse_encoding (s, Params::raw_output_format);
+    }
+  if (ap.parse_opt ("--raw-input-bits", i))
+    {
+      update_raw_bits (Params::raw_input_format, i);
+    }
+  if (ap.parse_opt ("--raw-output-bits", i))
+    {
+      update_raw_bits (Params::raw_output_format, i);
+    }
+  if (ap.parse_opt ("--raw-bits", i))
+    {
+      update_raw_bits (Params::raw_input_format, i);
+      update_raw_bits (Params::raw_output_format, i);
     }
   if (ap.parse_opt ("--raw-channels", i))
     {
@@ -960,10 +1006,12 @@ main (int argc, char **argv)
   else if (ap.parse_cmd ("test-gen-noise"))
     {
       parse_shared_options (ap);
+      int bits = 16;
+      ap.parse_opt ("--bits", bits);
 
       Key key = parse_key (ap);
       args = parse_positional (ap, "output_wav", "seconds", "sample_rate");
-      return test_gen_noise (key, args[0], atof_or_die (args[1].c_str()), atoi_or_die (args[2].c_str()));
+      return test_gen_noise (key, args[0], atof_or_die (args[1].c_str()), atoi_or_die (args[2].c_str()), bits);
     }
   else if (ap.parse_cmd ("test-change-speed"))
     {
@@ -979,6 +1027,13 @@ main (int argc, char **argv)
       args = parse_positional (ap, "input_wav", "output_wav", "new_rate");
       return test_resample (args[0], args[1], atoi_or_die (args[2].c_str()));
     }
+  else if (ap.parse_cmd ("test-info"))
+    {
+      parse_shared_options (ap);
+
+      args = parse_positional (ap, "input_wav", "property");
+      return test_info (args[0], args[1]);
+    }
   else if (ap.remaining_args().size())
     {
       string s = ap.remaining_args().front();
