@@ -436,7 +436,6 @@ hls_prepare (const string& in_dir, const string& out_dir, const string& filename
   };
   vector<Segment> segments;
   char buffer[1024];
-  int line = 1;
   const regex blank_re (R"(\s*(#.*)?)");
   while (fgets (buffer, 1024, in_file))
     {
@@ -460,7 +459,6 @@ hls_prepare (const string& in_dir, const string& out_dir, const string& filename
           segment.name = s;
           segments.push_back (segment);
         }
-      line++;
     }
   for (auto& segment : segments)
     {
@@ -484,6 +482,13 @@ hls_prepare (const string& in_dir, const string& out_dir, const string& filename
           error ("audiowmark: hls segment '%s' is not encoded using AAC\n", segname.c_str());
           return 1;
         }
+      int segment_channels = atoi (params["channels"].c_str());
+      if (segment_channels != audio_master_data.n_channels())
+        {
+          error ("audiowmark: number of channels mismatch:\n - hls segment '%s' has %d channels\n - audio master '%s' has %d channels\n",
+                 segname.c_str(), segment_channels, audio_master.c_str(), audio_master_data.n_channels());
+          return 1;
+        }
 
       /* get segment parameters */
       if (params["channel_layout"].empty())
@@ -563,6 +568,7 @@ hls_prepare (const string& in_dir, const string& out_dir, const string& filename
       SFOutputStream out_stream;
       err = out_stream.open (&full_flac_mem,
                              audio_master_data.n_channels(), audio_master_data.sample_rate(), audio_master_data.bit_depth(),
+                             Encoding::SIGNED, /* flac does not support floating point audio */
                              SFOutputStream::OutFormat::FLAC);
       if (err)
         {
